@@ -1,5 +1,6 @@
 """Helper functions to download."""
 import contextlib
+import ctypes
 import errno
 import glob
 import os
@@ -118,6 +119,43 @@ def mkdir_p(path):
             raise
 
 
+def create_symlink(executable, executable_link):
+    """Symlink executable to executable_link."""
+    link_method = os.symlink
+    if os.name == "nt":
+        # os.symlink is not supported on Windows, use a direct method instead.
+        def symlink_ms(source, symlink_name):
+            """Provide symlink for Windows."""
+            csl = ctypes.windll.kernel32.CreateSymbolicLinkW
+            csl.argtypes = (ctypes.c_wchar_p, ctypes.c_wchar_p, ctypes.c_uint32)
+            csl.restype = ctypes.c_ubyte
+            flags = 1 if os.path.isdir(source) else 0
+            if csl(symlink_name, source.replace("/", "\\"), flags) == 0:
+                raise ctypes.WinError()
+
+        link_method = symlink_ms
+
+    try:
+        link_method(executable, executable_link)
+        LOGGER.debug("Symlink created.", executable=executable, executable_link=executable_link)
+
+    except OSError as exc:
+        if exc.errno == errno.EEXIST:
+            LOGGER.warning("Symlink already exists.", exc=exc)
+            if os.name != "nt":
+                LOGGER.warning(
+                    "Removing old symlink & trying again", executable_link=executable_link
+                )
+                os.remove(executable_link)
+                link_method(executable, executable_link)
+                LOGGER.debug(
+                    "Symlink created.", executable=executable, executable_link=executable_link
+                )
+            pass
+        else:
+            raise
+
+
 def symlink_version(suffix, installed_dir, link_dir=None):
     """
     Symlink the binaries in the 'installed_dir' to the 'link_dir'.
@@ -146,33 +184,10 @@ def symlink_version(suffix, installed_dir, link_dir=None):
         else:
             link_name = executable
 
-        try:
-            executable = os.path.join(bin_dir, executable)
-            executable_link = os.path.join(link_dir, link_name)
+        executable = os.path.join(bin_dir, executable)
+        executable_link = os.path.join(link_dir, link_name)
 
-            link_method = os.symlink
-            if os.name == "nt":
-                # os.symlink is not supported on Windows, use a direct method instead.
-                def symlink_ms(source, symlink_name):
-                    """Provide symlink for Windows."""
-                    import ctypes
-
-                    csl = ctypes.windll.kernel32.CreateSymbolicLinkW
-                    csl.argtypes = (ctypes.c_wchar_p, ctypes.c_wchar_p, ctypes.c_uint32)
-                    csl.restype = ctypes.c_ubyte
-                    flags = 1 if os.path.isdir(source) else 0
-                    if csl(symlink_name, source.replace("/", "\\"), flags) == 0:
-                        raise ctypes.WinError()
-
-                link_method = symlink_ms
-            link_method(executable, executable_link)
-            LOGGER.debug("Symlink created.", executable=executable, executable_link=executable_link)
-
-        except OSError as exc:
-            if exc.errno == errno.EEXIST:
-                pass
-            else:
-                raise
+        create_symlink(executable, executable_link)
 
     LOGGER.info("Symlinks for all executables are created in the directory.", link_dir=link_dir)
     return link_dir
