@@ -79,15 +79,36 @@ def get_merge_base_commit(version: str) -> Optional[str]:
     """Get merge-base commit hash between origin/master and version."""
     cmd = ["git", "merge-base", "origin/master", f"origin/v{version}"]
     result = subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=False)
-    if result.returncode:
+
+    if result.returncode != 0:
+        curr_branch_cmd = ["git", "rev-parse", "--abbrev-ref", "HEAD"]
+        curr_branch_res = subprocess.run(
+            curr_branch_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=False
+        )
+
+        if curr_branch_res.stdout.decode("utf-8").strip() == "master":
+            LOGGER.warning(
+                "Git command failed.",
+                cmd=cmd,
+                error=result.stderr.decode("utf-8").strip(),
+            )
+            LOGGER.warning("Falling back to the latest starting from the current commit.")
+
+            cmd = ["git", "rev-parse", "--verify", "HEAD"]
+            result = subprocess.run(
+                cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=False
+            )
+
+    if result.returncode != 0:
         LOGGER.warning(
-            "Git merge-base command failed. Falling back to latest master",
+            "Git command failed.",
             cmd=cmd,
             error=result.stderr.decode("utf-8").strip(),
         )
+        LOGGER.warning("Falling back to the latest.")
         return None
     commit_hash = result.stdout.decode("utf-8").strip()
-    LOGGER.info("Found merge-base commit.", cmd=cmd, commit=commit_hash)
+    LOGGER.info("Found commit.", cmd=cmd, commit=commit_hash)
     return commit_hash
 
 
