@@ -34,6 +34,7 @@ import requests
 from db_contrib_tool.plugin import PluginInterface, Subcommand, SubcommandResult
 
 sys.path.append(str(Path(os.getcwd(), __file__).parent.parent))
+from db_contrib_tool.utils.build_system_options import PathOptions
 from db_contrib_tool.utils.oauth import Configs, get_oauth_credentials
 
 SUBCOMMAND = "symbolize"
@@ -157,6 +158,7 @@ class PathResolver(object):
             scope=self.scope,
         )
         self.http_client = requests.Session()
+        self.path_options = PathOptions()
 
         # create cache dir if it doesn't exist
         if not os.path.exists(self.cache_dir):
@@ -284,6 +286,17 @@ class PathResolver(object):
                     f"{self.host}/find_by_id", params={"build_id": build_id}
                 )
                 if response.status_code != 200:
+                    # if we could not find the path of binary, that might be system library.
+                    # we can try using frame's own `path` data.
+                    # symbolization can succeed only if that binary exists on local
+                    # machine (more specifically: in the given path).
+                    system_path = soinfo.get("path")
+                    if system_path:
+                        sys.stdout.write(
+                            f"Could not find path of binary from symbolizer web service. Trying to use the "
+                            f"provided path: {system_path}\n"
+                        )
+                        return system_path
                     sys.stderr.write(
                         f"Server returned unsuccessful status: {response.status_code}, "
                         f"response body: {response.text}\n"
@@ -323,7 +336,9 @@ class PathResolver(object):
         if not binary_name.endswith(".debug") and not binary_name.endswith(".so"):
             binary_name = f"{binary_name}.debug"
 
-        return os.path.join(path, binary_name)
+        inner_folder_name = self.path_options.get_binary_folder_name(binary_name)
+
+        return os.path.join(path, inner_folder_name, binary_name)
 
 
 class Symbolizer(Subcommand):
@@ -400,8 +415,6 @@ class Symbolizer(Subcommand):
                 "Please provide the backtrace through stdin for symbolization;"
                 "e.g. `your/symbolization/command < /file/with/stacktrace`"
             )
-        trace_doc = trace_doc[trace_doc.find("{") :]
-        trace_doc = json.JSONDecoder().raw_decode(trace_doc)[0]
 
         # Search the trace_doc for an object having "backtrace" and "processInfo" keys.
         def bt_search(obj):
@@ -416,11 +429,20 @@ class Symbolizer(Subcommand):
                 pass
             return None
 
-        trace_doc = bt_search(trace_doc)
-
-        if not trace_doc:
+        # given a log file including traceback,
+        # we try to find traceback from that file, analyzing each line until we find it
+        for line in trace_doc.splitlines():
+            possible_trace_doc = line[line.find("{") :]
+            try:
+                possible_trace_doc = json.JSONDecoder().raw_decode(possible_trace_doc)[0]
+                trace_doc = bt_search(possible_trace_doc)
+                if trace_doc:
+                    break
+            except json.JSONDecodeError:
+                pass
+        else:
             print("could not find json backtrace object in input", file=sys.stderr)
-            return SubcommandResult.FAIL
+            exit(1)
 
         output_fn = None
         if self.output_format == "json":
@@ -591,7 +613,11 @@ class Symbolizer(Subcommand):
                 for sframe in symbinfo:
                     outfile.write(" {file:s}:{line:d}:{column:d}: {fn:s}\n".format(**sframe))
             else:
-                outfile.write(" Couldn't extract symbols: {path:s}!!!\n".format(**frame))
+                outfile.write(
+                    " Couldn't extract symbols: path={path}\n".format(
+                        path=frame.get("path", "no value found")
+                    )
+                )
 
 
 class SymbolizerPlugin(PluginInterface):
