@@ -2,6 +2,9 @@
 
 import os
 import tempfile
+from typing import Any, Dict
+
+import yaml
 
 
 def mkdtemp_in_build_dir():
@@ -24,3 +27,14 @@ def build_hygienic_bin_path(parent=None, child=None):
         res = pjoin(res, child)
 
     return res
+
+
+def read_yaml_file(path: str) -> Dict[str, Any]:
+    """
+    Read the yaml file at the given path and return the contents.
+
+    :param path: Path to file to read.
+    :return: Contents of given file.
+    """
+    with open(path) as file_handle:
+        return yaml.safe_load(file_handle)
